#
# Conditional build:
%bcond_without	tests		# build without tests
%bcond_without	mysqlnd		# without mysqlnd support in mysql related extensions

%define		rel		7
%define		commit	ca514c4
%define		php_name	php%{?php_suffix}
%define		modname	mysql
Summary:	Legacy MySQL extension
Summary(pl.UTF-8):	Moduł bazy danych MySQL dla PHP
Summary(pt_BR.UTF-8):	Um módulo para aplicações PHP que usam bancos de dados MySQL
Name:		%{php_name}-pecl-%{modname}
Version:	1.0.0
Release:	%{rel}.%{commit}
License:	PHP 3.01
Group:		Development/Languages/PHP
# https://github.com/php/pecl-database-mysql
Source0:	https://github.com/php/pecl-database-mysql/archive/%{commit}/php-pecl-%{modname}-%{version}-%{commit}.tar.gz
# Source0-md5:	352114d54e0889d999577f9db8c06a74
Patch0:		revert-deprecate-ext-mysql.patch
URL:		https://secure.php.net/manual/en/book.mysql.php
%{?with_tests:BuildRequires:    %{php_name}-cli}
BuildRequires:	%{php_name}-devel >= 4:7.0.0
%{?with_mysqlnd:BuildRequires:	%{php_name}-mysqlnd}
BuildRequires:	rpmbuild(macros) >= 1.666
%if %{with tests}
BuildRequires:	%{php_name}-cli
BuildRequires:	%{php_name}-pcre
%endif
%{?with_mysqlnd:Requires:	%{php_name}-mysqlnd}
%{?requires_php_extension}
Provides:	php(mysql) = %{version}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
This is a dynamic shared object (DSO) for PHP that will add MySQL
database support.

This extension provides the mysql family of functions that were
provided with PHP 3-5. These functions have been superseded by MySQLi
and PDO_MySQL, which continue to be bundled with PHP 7.

You are strongly encouraged to port your code to use either MySQLi or
PDO_MySQL, as this extension is not maintained and is available for
historical reasons only.

%prep
%setup -qc -n %{name}-%{version}-%{commit}
mv pecl-database-%{modname}-*/* .
%patch0 -p1

cat <<'EOF' > run-tests.sh
#!/bin/sh
export NO_INTERACTION=1 REPORT_EXIT_STATUS=1 MALLOC_CHECK_=2
exec %{__make} test \
	PHP_EXECUTABLE=%{__php} \
	PHP_TEST_SHARED_SYSTEM_EXTENSIONS="%{?with_mysqlnd:mysqlnd}" \
	RUN_TESTS_SETTINGS="-q $*"
EOF
chmod +x run-tests.sh

xfail() {
	local t=$1
	test -f $t
	cat >> $t <<-EOF

	--XFAIL--
	Skip
	EOF
}

while read line; do
	t=${line##*\[}; t=${t%\]}
	xfail $t
done << 'EOF'
mysql_escape_string() [tests/mysql_escape_string.phpt]
mysql_get_client_info() [tests/mysql_get_client_info.phpt]
ReflectionFunction to check API [tests/mysql_reflection_functions.phpt]
EOF

%build
phpize
%configure \
	--with-mysql=shared,%{!?with_mysqlnd:/usr}%{?with_mysqlnd:mysqlnd} \
	--with-mysql-sock=/var/lib/mysql/mysql.sock \
	--with-zlib-dir=shared,/usr \

%{__make}

# simple module load test
%{__php} -n -q -d display_errors=off \
	-d extension_dir=modules \
%if %{with mysqlnd}
	-d extension=%{php_extensiondir}/mysqlnd.so \
%endif
	-d extension=%{modname}.so \
	-m > modules.log
grep "^%{modname}$" modules.log

%if %{with tests}
./run-tests.sh --show-diff
%endif

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	EXTENSION_DIR=%{php_extensiondir} \
	INSTALL_ROOT=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d
cat <<'EOF' > $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d/%{modname}.ini
; Enable %{modname} extension module
extension=%{modname}.so
EOF

%clean
rm -rf $RPM_BUILD_ROOT

%post
%php_webserver_restart

%postun
if [ "$1" = 0 ]; then
	%php_webserver_restart
fi

%files
%defattr(644,root,root,755)
%doc README.md CREDITS LICENSE
%config(noreplace) %verify(not md5 mtime size) %{php_sysconfdir}/conf.d/%{modname}.ini
%attr(755,root,root) %{php_extensiondir}/%{modname}.so
%changelog
* Thu Dec 28 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/php-pecl-mysql.git;a=log;h=auto/th/php-pecl-mysql-1.0.0-7.ca514c4

* Mon Dec 27 2021 Elan Ruusamäe <glen@pld-linux.org> a09f25f
- Fix module load test

* Mon Dec 27 2021 Elan Ruusamäe <glen@pld-linux.org> bda1ea0
- Up to ca514c4 commit

* Thu Nov 26 2020 Elan Ruusamäe <glen@pld-linux.org> 3415fb6
- Release 6

* Thu Nov 26 2020 Elan Ruusamäe <glen@pld-linux.org> 8b818a2
- Add failing tests to xfail

* Thu Nov 26 2020 Elan Ruusamäe <glen@pld-linux.org> 485787f
- Always perform module load test

* Thu Nov 26 2020 Elan Ruusamäe <glen@pld-linux.org> 5d9b9fd
- Update tests to add xfail support

* Mon Nov 23 2020 Elan Ruusamäe <glen@pld-linux.org> 3c6d6e5
- Update to 580d46c to support php 8.0

* Mon Sep 23 2019 Elan Ruusamäe <glen@delfi.ee> a13f631
- Rebuild with 7.4 RC2
- release 2 (by relup.sh)

* Thu Jun 20 2019 Elan Ruusamäe <glen@pld-linux.org> bb11f1c
- revert deprecation messages

* Thu Jun 20 2019 Elan Ruusamäe <glen@pld-linux.org> aabe5a7
- update to d7643af

* Mon Nov 12 2018 Elan Ruusamäe <glen@pld-linux.org> 760fe9a
- up to 1.0.0-386776d (php 7.3 support)

* Fri Jan 13 2017 Arkadiusz Miśkiewicz <arekm@maven.pl> 551db2b
- rel 3; latest snap

* Tue Nov 15 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 547e0c1
- rel 2; mysqlnd is also required runtime: 'PHP Warning:  Cannot load module 'mysql' because required module 'mysqlnd' is not loaded in Unknown on line 0'

* Thu Nov 05 2015 Elan Ruusamäe <glen@delfi.ee> 0584b02
- up to 1.0.0-dev

* Mon Sep 28 2015 Elan Ruusamäe <glen@delfi.ee> 3a4949f
- md5 update

* Sun Sep 27 2015 Elan Ruusamäe <glen@delfi.ee> 1bd311a
- up to 617e510, version is "1.0" in .c file

* Sun May 24 2015 Elan Ruusamäe <glen@delfi.ee> a4c23b9
- new, version 1.0.0

